@@ -77,6 +77,12 @@ impl From<i32> for SignedLevel {
     }
 }
 
+impl fmt::Display for SignedLevel {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "{}", self.value())
+    }
+}
+
 impl RandomValue for SignedLevel {
     type T = i8;
 
@@ -195,6 +201,10 @@ impl UnsignedDepth {
     pub fn as_byte(&self) -> u8 {
         self.0
     }
+
+    pub fn value(&self) -> u8 {
+        self.0
+    }
 }
 
 impl From<u8> for UnsignedDepth {
@@ -203,6 +213,12 @@ impl From<u8> for UnsignedDepth {
     }
 }
 
+impl fmt::Display for UnsignedDepth {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "{}", self.value())
+    }
+}
+
 /// Depth (0~100).
 #[derive(Debug, Clone, Copy)]
 pub struct Depth(u8);
@@ -305,6 +321,10 @@ impl SmallDepth {
     pub fn as_byte(&self) -> u8 {
         self.0
     }
+
+    pub fn value(&self) -> u8 {
+        self.0
+    }
 }
 
 impl From<u8> for SmallDepth {
@@ -313,6 +333,12 @@ impl From<u8> for SmallDepth {
     }
 }
 
+impl fmt::Display for SmallDepth {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "{}", self.value())
+    }
+}
+
 /// Coarse tuning (-24...+24) (in SysEx 40...88)
 #[derive(Debug, Clone, Copy)]
 pub struct Coarse(i8);
